@@ -12,6 +12,8 @@ static const char* FILE_NAME = "R/OP/Matrix/Double.cpp";
 
 int32_t SPVM__R__OP__Matrix__Double___mul(SPVM_ENV* env, SPVM_VALUE* stack) {
   
+  int32_t e = 0;
+  
   void* obj_ret_data_ref = stack[0].oval;
   
   int32_t* ret_nrow_ref = stack[1].iref;
@@ -19,14 +21,14 @@ int32_t SPVM__R__OP__Matrix__Double___mul(SPVM_ENV* env, SPVM_VALUE* stack) {
   int32_t* ret_ncol_ref = stack[2].iref;
   
   void* obj_x_data = stack[3].oval;
-  double* x_data = env->get_elems_double(env, stack, obj_x_data);
+  double* x_data = (double*)env->get_elems_double(env, stack, obj_x_data);
   
   int32_t x_nrow = stack[4].ival;
   
   int32_t x_ncol = stack[5].ival;
   
   void* obj_y_data = stack[6].oval;
-  double* y_data = env->get_elems_double(env, stack, obj_y_data);
+  double* y_data = (double*)env->get_elems_double(env, stack, obj_y_data);
   
   int32_t y_nrow = stack[7].ival;
   
@@ -41,44 +43,7 @@ int32_t SPVM__R__OP__Matrix__Double___mul(SPVM_ENV* env, SPVM_VALUE* stack) {
   int32_t ret_length = ret_matrix.rows() * ret_matrix.cols();
   void* obj_ret_data = env->new_double_array(env, stack, ret_length);
   
-  double* ret_data = env->get_elems_double(env, stack, obj_ret_data);
-  
-  memcpy(ret_data, ret_matrix.data(), sizeof(double) * ret_length);
-  
-  env->set_elem_object(env, stack, obj_ret_data_ref, 0, obj_ret_data);
-  
-  *ret_nrow_ref = ret_matrix.rows();
-  
-  *ret_ncol_ref = ret_matrix.cols();
-  
-  return 0;
-}
-
-int32_t SPVM__R__OP__Matrix__Double___solve(SPVM_ENV* env, SPVM_VALUE* stack) {
-  
-  void* obj_ret_data_ref = stack[0].oval;
-  
-  int32_t* ret_nrow_ref = stack[1].iref;
-  
-  int32_t* ret_ncol_ref = stack[2].iref;
-  
-  void* obj_x_data = stack[3].oval;
-  double* x_data = env->get_elems_double(env, stack, obj_x_data);
-  
-  int32_t x_nrow = stack[4].ival;
-  
-  int32_t x_ncol = stack[5].ival;
-  
-  Eigen::Matrix<double, Eigen::Dynamic, Eigen::Dynamic> x_matrix = Eigen::Map<Eigen::Matrix<double, Eigen::Dynamic, Eigen::Dynamic>>(x_data, x_nrow, x_ncol);
-  
-  Eigen::Matrix<double, Eigen::Dynamic, Eigen::Dynamic> ret_matrix = x_matrix;
-  
-  ret_matrix.inverse();
-  
-  int32_t ret_length = ret_matrix.rows() * ret_matrix.cols();
-  void* obj_ret_data = env->new_double_array(env, stack, ret_length);
-  
-  double* ret_data = env->get_elems_double(env, stack, obj_ret_data);
+  double* ret_data = (double*)env->get_elems_double(env, stack, obj_ret_data);
   
   memcpy(ret_data, ret_matrix.data(), sizeof(double) * ret_length);
   
@@ -93,6 +58,8 @@ int32_t SPVM__R__OP__Matrix__Double___solve(SPVM_ENV* env, SPVM_VALUE* stack) {
 
 int32_t SPVM__R__OP__Matrix__Double___t(SPVM_ENV* env, SPVM_VALUE* stack) {
   
+  int32_t e = 0;
+  
   void* obj_ret_data_ref = stack[0].oval;
   
   int32_t* ret_nrow_ref = stack[1].iref;
@@ -100,7 +67,7 @@ int32_t SPVM__R__OP__Matrix__Double___t(SPVM_ENV* env, SPVM_VALUE* stack) {
   int32_t* ret_ncol_ref = stack[2].iref;
   
   void* obj_x_data = stack[3].oval;
-  double* x_data = env->get_elems_double(env, stack, obj_x_data);
+  double* x_data = (double*)env->get_elems_double(env, stack, obj_x_data);
   
   int32_t x_nrow = stack[4].ival;
   
@@ -115,7 +82,7 @@ int32_t SPVM__R__OP__Matrix__Double___t(SPVM_ENV* env, SPVM_VALUE* stack) {
   int32_t ret_length = ret_matrix.rows() * ret_matrix.cols();
   void* obj_ret_data = env->new_double_array(env, stack, ret_length);
   
-  double* ret_data = env->get_elems_double(env, stack, obj_ret_data);
+  double* ret_data = (double*)env->get_elems_double(env, stack, obj_ret_data);
   
   memcpy(ret_data, ret_matrix.data(), sizeof(double) * ret_length);
   
@@ -130,6 +97,8 @@ int32_t SPVM__R__OP__Matrix__Double___t(SPVM_ENV* env, SPVM_VALUE* stack) {
 
 int32_t SPVM__R__OP__Matrix__Double___det(SPVM_ENV* env, SPVM_VALUE* stack) {
   
+  int32_t e = 0;
+  
   void* obj_ret_data_ref = stack[0].oval;
   
   int32_t* ret_nrow_ref = stack[1].iref;
@@ -137,7 +106,7 @@ int32_t SPVM__R__OP__Matrix__Double___det(SPVM_ENV* env, SPVM_VALUE* stack) {
   int32_t* ret_ncol_ref = stack[2].iref;
   
   void* obj_x_data = stack[3].oval;
-  double* x_data = env->get_elems_double(env, stack, obj_x_data);
+  double* x_data = (double*)env->get_elems_double(env, stack, obj_x_data);
   
   int32_t x_nrow = stack[4].ival;
   
@@ -150,7 +119,7 @@ int32_t SPVM__R__OP__Matrix__Double___det(SPVM_ENV* env, SPVM_VALUE* stack) {
   int32_t ret_length = 1;
   void* obj_ret_data = env->new_double_array(env, stack, ret_length);
   
-  double* ret_data = env->get_elems_double(env, stack, obj_ret_data);
+  double* ret_data = (double*)env->get_elems_double(env, stack, obj_ret_data);
   
   memcpy(ret_data, &ret, sizeof(double) * ret_length);
   
@@ -163,7 +132,9 @@ int32_t SPVM__R__OP__Matrix__Double___det(SPVM_ENV* env, SPVM_VALUE* stack) {
   return 0;
 }
 
-int32_t SPVM__R__OP__Matrix__Double___eigen(SPVM_ENV* env, SPVM_VALUE* stack) {
+int32_t SPVM__R__OP__Matrix__Double___solve(SPVM_ENV* env, SPVM_VALUE* stack) {
+  
+  int32_t e = 0;
   
   void* obj_ret_data_ref = stack[0].oval;
   
@@ -172,7 +143,46 @@ int32_t SPVM__R__OP__Matrix__Double___eigen(SPVM_ENV* env, SPVM_VALUE* stack) {
   int32_t* ret_ncol_ref = stack[2].iref;
   
   void* obj_x_data = stack[3].oval;
-  double* x_data = env->get_elems_double(env, stack, obj_x_data);
+  double* x_data = (double*)env->get_elems_double(env, stack, obj_x_data);
+  
+  int32_t x_nrow = stack[4].ival;
+  
+  int32_t x_ncol = stack[5].ival;
+  
+  Eigen::Matrix<double, Eigen::Dynamic, Eigen::Dynamic> x_matrix = Eigen::Map<Eigen::Matrix<double, Eigen::Dynamic, Eigen::Dynamic>>(x_data, x_nrow, x_ncol);
+  
+  Eigen::Matrix<double, Eigen::Dynamic, Eigen::Dynamic> ret_matrix = x_matrix;
+  
+  ret_matrix.inverse();
+  
+  int32_t ret_length = ret_matrix.rows() * ret_matrix.cols();
+  void* obj_ret_data = env->new_double_array(env, stack, ret_length);
+  
+  double* ret_data = (double*)env->get_elems_double(env, stack, obj_ret_data);
+  
+  memcpy(ret_data, ret_matrix.data(), sizeof(double) * ret_length);
+  
+  env->set_elem_object(env, stack, obj_ret_data_ref, 0, obj_ret_data);
+  
+  *ret_nrow_ref = ret_matrix.rows();
+  
+  *ret_ncol_ref = ret_matrix.cols();
+  
+  return 0;
+}
+
+int32_t SPVM__R__OP__Matrix__Double___eigen(SPVM_ENV* env, SPVM_VALUE* stack) {
+  
+  int32_t e = 0;
+  
+  void* obj_ret_data_ref = stack[0].oval;
+  
+  int32_t* ret_nrow_ref = stack[1].iref;
+  
+  int32_t* ret_ncol_ref = stack[2].iref;
+  
+  void* obj_x_data = stack[3].oval;
+  double* x_data = (double*)env->get_elems_double(env, stack, obj_x_data);
   
   int32_t x_nrow = stack[4].ival;
   
@@ -184,14 +194,14 @@ int32_t SPVM__R__OP__Matrix__Double___eigen(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   Eigen::SelfAdjointEigenSolver<Eigen::Matrix<double, Eigen::Dynamic, Eigen::Dynamic>> eigen_solver(x_matrix);
   
-  Eigen::VectorXd eigen_values = eigen_solver.eigenvalues();
+  Eigen::Matrix<double, Eigen::Dynamic, 1> eigen_values = eigen_solver.eigenvalues();
   
   Eigen::Matrix<double, Eigen::Dynamic, Eigen::Dynamic> eigen_vectors = eigen_solver.eigenvectors();
   
   int32_t ret_length = eigen_vectors.rows() * eigen_vectors.cols();
   void* obj_ret_data = env->new_double_array(env, stack, ret_length);
   
-  double* ret_data = env->get_elems_double(env, stack, obj_ret_data);
+  double* ret_data = (double*)env->get_elems_double(env, stack, obj_ret_data);
   
   memcpy(ret_data, eigen_vectors.data(), sizeof(double) * ret_length);
   
@@ -201,11 +211,13 @@ int32_t SPVM__R__OP__Matrix__Double___eigen(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   *ret_ncol_ref = eigen_vectors.cols();
   
-  void* eigen_values_data = env->new_double_array(env, stack, eigen_values.size());
+  void* obj_eigen_values_data = env->new_double_array(env, stack, eigen_values.size());
+  
+  double* eigen_values_data = (double*)env->get_elems_double(env, stack, obj_eigen_values_data);
   
   memcpy(eigen_values_data, eigen_values.data(), sizeof(double) * eigen_values.size());
   
-  env->set_elem_object(env, stack, obj_eigen_values_data_ref, 0, eigen_values_data);
+  env->set_elem_object(env, stack, obj_eigen_values_data_ref, 0, obj_eigen_values_data);
   
   return 0;
 }
